==> DNAcopy_1.18.0.zip: DNAcopy/doc/DNAcopy.R <==
###################################################
### chunk number 1: 
###################################################
library(DNAcopy)


###################################################
### chunk number 2: 
###################################################
data(coriell)


###################################################
### chunk number 3: 
###################################################
CNA.object <- CNA(cbind(coriell$Coriell.05296),
                  coriell$Chromosome,coriell$Position,
                  data.type="logratio",sampleid="c05296")


###################################################
### chunk number 4: 
###################################################
smoothed.CNA.object <- smooth.CNA(CNA.object)


###################################################
### chunk number 5: 
###################################################
segment.smoothed.CNA.object <- segment(smoothed.CNA.object, verbose=1)


###################################################
### chunk number 6: 
###################################################
plot(segment.smoothed.CNA.object, plot.type="w")


###################################################
### chunk number 7: 
###################################################
plot(segment.smoothed.CNA.object, plot.type="s") 


###################################################
### chunk number 8: 
###################################################
plot(segment.smoothed.CNA.object, plot.type="p")


###################################################
### chunk number 9: 
###################################################
sdundo.CNA.object <- segment(smoothed.CNA.object, 
                             undo.splits="sdundo", 
                             undo.SD=3,verbose=1)


###################################################
### chunk number 10: 
###################################################
plot(sdundo.CNA.object,plot.type="s")

==> DNAcopy_1.24.0.zip: DNAcopy/doc/DNAcopy.R <==
###################################################
### chunk number 1: 
###################################################
#line 75 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpO3317k/R.INSTALL28474366/DNAcopy/inst/doc/DNAcopy.Rnw"
library(DNAcopy)


###################################################
### chunk number 2: 
###################################################
#line 79 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpO3317k/R.INSTALL28474366/DNAcopy/inst/doc/DNAcopy.Rnw"
data(coriell)


###################################################
### chunk number 3: 
###################################################
#line 86 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpO3317k/R.INSTALL28474366/DNAcopy/inst/doc/DNAcopy.Rnw"
CNA.object <- CNA(cbind(coriell$Coriell.05296),
                  coriell$Chromosome,coriell$Position,
                  data.type="logratio",sampleid="c05296")


###################################################
### chunk number 4: 
###################################################
#line 97 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpO3317k/R.INSTALL28474366/DNAcopy/inst/doc/DNAcopy.Rnw"
smoothed.CNA.object <- smooth.CNA(CNA.object)


###################################################
### chunk number 5: 
###################################################
#line 106 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpO3317k/R.INSTALL28474366/DNAcopy/inst/doc/DNAcopy.Rnw"
segment.smoothed.CNA.object <- segment(smoothed.CNA.object, verbose=1)


###################################################
### chunk number 6: 
###################################################
#line 121 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpO3317k/R.INSTALL28474366/DNAcopy/inst/doc/DNAcopy.Rnw"
plot(segment.smoothed.CNA.object, plot.type="w")


###################################################
### chunk number 7: 
###################################################
#line 130 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpO3317k/R.INSTALL28474366/DNAcopy/inst/doc/DNAcopy.Rnw"
plot(segment.smoothed.CNA.object, plot.type="s") 


###################################################
### chunk number 8: 
###################################################
#line 158 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpO3317k/R.INSTALL28474366/DNAcopy/inst/doc/DNAcopy.Rnw"
plot(segment.smoothed.CNA.object, plot.type="p")


###################################################
### chunk number 9: 
###################################################
#line 170 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpO3317k/R.INSTALL28474366/DNAcopy/inst/doc/DNAcopy.Rnw"
sdundo.CNA.object <- segment(smoothed.CNA.object, 
                             undo.splits="sdundo", 
                             undo.SD=3,verbose=1)


###################################################
### chunk number 10: 
###################################################
#line 178 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpO3317k/R.INSTALL28474366/DNAcopy/inst/doc/DNAcopy.Rnw"
plot(sdundo.CNA.object,plot.type="s")
